@@ -820,6 +820,12 @@ impl<'a, C> ComponentAmalgamation<'a, C> {
     pub fn other_revocations(&self) -> impl Iterator<Item=&'a Signature> + Send + Sync {
         self.bundle().other_revocations().iter()
     }
+
+    /// Returns all of the component's signatures.
+    pub fn signatures(&self)
+                      -> impl Iterator<Item = &'a Signature> + Send + Sync {
+        self.bundle().signatures()
+    }
 }
 
 macro_rules! impl_with_policy {
@@ -1187,6 +1193,18 @@ impl<'a, C> ValidComponentAmalgamation<'a, C>
           .filter(move |sig| self.cert.policy().signature(sig,
             HashAlgoSecurity::CollisionResistance).is_ok())
     }
+
+
+    /// Returns all of the component's signatures.
+    ///
+    /// This method only returns signatures that are valid under the
+    /// current policy.
+    pub fn signatures(&self)
+                      -> impl Iterator<Item = &Signature> + Send + Sync {
+        std::ops::Deref::deref(self).signatures()
+          .filter(move |sig| self.cert.policy().signature(sig,
+            HashAlgoSecurity::CollisionResistance).is_ok())
+    }
 }
 
 impl<'a, C> seal::Sealed for ValidComponentAmalgamation<'a, C> {}
