@@ -122,6 +122,9 @@ pub struct ComponentBundle<C> {
     // designated revokers.)
     pub(crate) certifications: Vec<Signature>,
 
+    // Attestation key signatures.
+    pub(crate) attestations: Vec<Signature>,
+
     // Self revocations.
     pub(crate) self_revocations: Vec<Signature>,
 
@@ -397,7 +400,7 @@ impl<C> ComponentBundle<C> {
     /// for (i, ka) in cert.keys().enumerate() {
     ///     eprintln!("Key #{} ({}) has {:?} self signatures",
     ///               i, ka.fingerprint(),
-    ///               ka.self_signatures().count());
+    ///               ka.bundle().self_signatures().len());
     /// }
     /// # Ok(()) }
     /// ```
@@ -426,7 +429,7 @@ impl<C> ComponentBundle<C> {
     /// for ua in cert.userids() {
     ///     eprintln!("User ID {} has {:?} unverified, third-party certifications",
     ///               String::from_utf8_lossy(ua.userid().value()),
-    ///               ua.certifications().count());
+    ///               ua.bundle().certifications().len());
     /// }
     /// # Ok(()) }
     /// ```
@@ -456,7 +459,7 @@ impl<C> ComponentBundle<C> {
     /// for u in cert.userids() {
     ///     eprintln!("User ID {} has {:?} revocation certificates.",
     ///               String::from_utf8_lossy(u.userid().value()),
-    ///               u.self_revocations().count());
+    ///               u.bundle().self_revocations().len());
     /// }
     /// # Ok(()) }
     /// ```
@@ -486,7 +489,7 @@ impl<C> ComponentBundle<C> {
     /// for u in cert.userids() {
     ///     eprintln!("User ID {} has {:?} unverified, third-party revocation certificates.",
     ///               String::from_utf8_lossy(u.userid().value()),
-    ///               u.other_revocations().count());
+    ///               u.bundle().other_revocations().len());
     /// }
     /// # Ok(()) }
     /// ```
@@ -494,6 +497,45 @@ impl<C> ComponentBundle<C> {
         &self.other_revocations
     }
 
+    /// Returns all of the component's signatures.
+    ///
+    /// Only the self-signatures are validated.  The signatures are
+    /// sorted first by type, then by creation time.  The self
+    /// revocations come first, then the self signatures,
+    /// certifications, and third-party revocations coming last.  This
+    /// function may return additional types of signatures that could
+    /// be associated to this component.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use sequoia_openpgp as openpgp;
+    /// # use openpgp::cert::prelude::*;
+    /// use openpgp::policy::StandardPolicy;
+    /// #
+    /// # fn main() -> openpgp::Result<()> {
+    /// let p = &StandardPolicy::new();
+    ///
+    /// # let (cert, _) =
+    /// #     CertBuilder::general_purpose(None, Some("alice@example.org"))
+    /// #     .generate()?;
+    /// for (i, ka) in cert.keys().enumerate() {
+    ///     eprintln!("Key #{} ({}) has {:?} signatures",
+    ///               i, ka.fingerprint(),
+    ///               ka.signatures().count());
+    /// }
+    /// # Ok(()) }
+    /// ```
+    pub fn signatures(&self)
+                      -> impl Iterator<Item = &Signature> + Send + Sync
+    {
+        self.self_revocations.iter()
+            .chain(self.self_signatures.iter())
+            .chain(self.attestations.iter())
+            .chain(self.certifications.iter())
+            .chain(self.other_revocations.iter())
+    }
+
     /// Returns the component's revocation status at time `t`.
     ///
     /// A component is considered to be revoked at time `t` if:
@@ -626,6 +668,7 @@ impl<C> ComponentBundle<C> {
         std::iter::once(p)
             .chain(self.self_revocations.into_iter().map(|s| s.into()))
             .chain(self.self_signatures.into_iter().map(|s| s.into()))
+            .chain(self.attestations.into_iter().map(|s| s.into()))
             .chain(self.certifications.into_iter().map(|s| s.into()))
             .chain(self.other_revocations.into_iter().map(|s| s.into()))
     }
@@ -674,6 +717,11 @@ impl<C> ComponentBundle<C> {
         self.self_signatures.sort_by(sig_cmp);
         self.self_signatures.iter_mut().for_each(sig_fixup);
 
+        self.attestations.sort_by(Signature::normalized_cmp);
+        self.attestations.dedup_by(sig_merge);
+        self.attestations.sort_by(sig_cmp);
+        self.attestations.iter_mut().for_each(sig_fixup);
+
         self.certifications.sort_by(Signature::normalized_cmp);
         self.certifications.dedup_by(sig_merge);
         // There is no need to sort the certifications, but doing so
