@@ -1017,19 +1017,19 @@ impl FromStr for HashAlgorithm {
     type Err = ();
 
     fn from_str(s: &str) -> result::Result<Self, ()> {
-        if s == "MD5" {
+        if s.eq_ignore_ascii_case("MD5") {
             Ok(HashAlgorithm::MD5)
-        } else if s == "SHA1" {
+        } else if s.eq_ignore_ascii_case("SHA1") {
             Ok(HashAlgorithm::SHA1)
-        } else if s == "RipeMD160" {
+        } else if s.eq_ignore_ascii_case("RipeMD160") {
             Ok(HashAlgorithm::RipeMD)
-        } else if s == "SHA256" {
+        } else if s.eq_ignore_ascii_case("SHA256") {
             Ok(HashAlgorithm::SHA256)
-        } else if s == "SHA384" {
+        } else if s.eq_ignore_ascii_case("SHA384") {
             Ok(HashAlgorithm::SHA384)
-        } else if s == "SHA512" {
+        } else if s.eq_ignore_ascii_case("SHA512") {
             Ok(HashAlgorithm::SHA512)
-        } else if s == "SHA224" {
+        } else if s.eq_ignore_ascii_case("SHA224") {
             Ok(HashAlgorithm::SHA224)
         } else {
             Err(())
@@ -1055,6 +1055,42 @@ impl fmt::Display for HashAlgorithm {
     }
 }
 
+impl HashAlgorithm {
+    /// Returns the text name of this algorithm.
+    ///
+    /// [Section 9.4 of RFC 4880] defines a textual representation of
+    /// hash algorithms.  This is used in cleartext signed messages
+    /// (see [Section 7 of RFC 4880]).
+    ///
+    ///   [Section 9.4 of RFC 4880]: https://tools.ietf.org/html/rfc4880#section-9.4
+    ///   [Section 7 of RFC 4880]: https://tools.ietf.org/html/rfc4880#section-7
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use sequoia_openpgp as openpgp;
+    /// # use openpgp::types::HashAlgorithm;
+    /// # fn main() -> openpgp::Result<()> {
+    /// assert_eq!(HashAlgorithm::RipeMD.text_name()?, "RIPEMD160");
+    /// # Ok(()) }
+    /// ```
+    pub fn text_name(&self) -> Result<&str> {
+        match self {
+            HashAlgorithm::MD5 =>    Ok("MD5"),
+            HashAlgorithm::SHA1 =>   Ok("SHA1"),
+            HashAlgorithm::RipeMD => Ok("RIPEMD160"),
+            HashAlgorithm::SHA256 => Ok("SHA256"),
+            HashAlgorithm::SHA384 => Ok("SHA384"),
+            HashAlgorithm::SHA512 => Ok("SHA512"),
+            HashAlgorithm::SHA224 => Ok("SHA224"),
+            HashAlgorithm::Private(_) =>
+                Err(Error::UnsupportedHashAlgorithm(*self).into()),
+            HashAlgorithm::Unknown(_) =>
+                Err(Error::UnsupportedHashAlgorithm(*self).into()),
+        }
+    }
+}
+
 #[cfg(test)]
 impl Arbitrary for HashAlgorithm {
     fn arbitrary<G: Gen>(g: &mut G) -> Self {
@@ -1127,6 +1163,12 @@ pub enum SignatureType {
 }
 assert_send_and_sync!(SignatureType);
 
+/// An attested key signature.
+#[allow(non_upper_case_globals)]
+pub(crate) const SignatureType__AttestedKey: SignatureType =
+    SignatureType::Unknown(0x16);
+
+
 impl From<u8> for SignatureType {
     fn from(u: u8) -> Self {
         match u {
@@ -1821,6 +1863,18 @@ mod tests {
         }
     }
 
+    quickcheck! {
+        fn hash_roundtrip_text_name(hash: HashAlgorithm) -> bool {
+            match hash {
+                HashAlgorithm::Private(_) | HashAlgorithm::Unknown(_) => true,
+                hash => {
+                    let s = hash.text_name().unwrap();
+                    hash == HashAlgorithm::from_str(s).unwrap()
+                }
+            }
+        }
+    }
+
     quickcheck! {
         fn hash_display(hash: HashAlgorithm) -> bool {
             let s = format!("{}", hash);
